[−][src]Struct gimli::constants::DwAddr
The encodings of the constants used in the DW_AT_address_class attribute.
There is only one value that is common to all target architectures. See Section 7.13.
Implementations
impl DwAddr[src][−]
pub fn static_string(&self) -> Option<&'static str>[src]